import { ConeGeometry, MathUtils, Mesh, MeshStandardMaterial } from './three.module.js';

function createCone(color, radius, height, xOffset, yOffset, zOffset) {

  const radialSegments = 50;

  const geometry = new ConeGeometry(
    radius, height, radialSegments);

  const material = new MeshStandardMaterial({ color: color });

  const cone = new Mesh(geometry, material);

  cone.position.x = xOffset;
  cone.position.y = yOffset;
  cone.position.z = zOffset;

  const radiansPerSecond = MathUtils.degToRad(30);

  // this method will be called once per frame
  cone.tick = (delta) => {
    // increase the cube's rotation each frame
    cone.rotation.z += radiansPerSecond * delta;
    cone.rotation.x += radiansPerSecond * delta;
    cone.rotation.y += radiansPerSecond * delta;
  };

  return cone;
}

export { createCone };
