import { CylinderGeometry, MathUtils, Mesh, MeshStandardMaterial } from './three.module.js';

function createCylinder(color, radiusTop, radiusBottom, height, xOffset, yOffset, zOffset) {

  const radialSegments = 50;

  const geometry = new CylinderGeometry(
    radiusTop, radiusBottom, height, radialSegments);

  const material = new MeshStandardMaterial({ color: color });

  const cylinder = new Mesh(geometry, material);

  cylinder.position.x = xOffset;
  cylinder.position.y = yOffset;
  cylinder.position.z = zOffset;


  const radiansPerSecond = MathUtils.degToRad(30);

  // this method will be called once per frame
  cylinder.tick = (delta) => {
    // increase the cube's rotation each frame
    cylinder.rotation.z += radiansPerSecond * delta;
    cylinder.rotation.x += radiansPerSecond * delta;
    cylinder.rotation.y += radiansPerSecond * delta;
  };

  return cylinder;
}

export { createCylinder };
